#
# spec file for package usb_modeswitch
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define source_name usb-modeswitch
%define date	20191128
%define _udevdir %(pkg-config --variable=udevdir udev)
Name:           usb_modeswitch
Version:        2.6.1
Release:        2.7
Summary:        A mode switching tool for controlling multiple-device USB gear
License:        GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            https://www.draisberghof.de/usb_modeswitch/
Source0:        https://www.draisberghof.de/usb_modeswitch/%{source_name}-%{version}.tar.bz2
Source1:        https://www.draisberghof.de/usb_modeswitch/%{source_name}-data-%{date}.tar.bz2
Source2:        https://www.draisberghof.de/usb_modeswitch/device_reference.txt
Source3:        https://www.draisberghof.de/usb_modeswitch/parameter_reference.txt
Patch1:         usb_modeswitch-fix_fsf_address.patch
Patch2:	harden_usb_modeswitch@.service.patch
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       tcl >= 8.4
Requires:       usb_modeswitch-data = %{version}
%{?systemd_requires}

%description
USB_ModeSwitch is a mode switching tool for controlling "flip flop"
(multiple device) USB gear. It allows so-called "Zero-CD" devices that
show up as USB storage initially to be switched into their more useful
"application mode". This is most common for UMTS/3G wireless WAN
devices.

%package data
Summary:        Data Files for USB Modeswitch
Group:          Hardware/Mobile
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
Data files for usb_modeswitch package.

%prep
%setup -q -a1 -n %{source_name}-%{version}
%patch1
%patch2 -p1

cp %{SOURCE2} .
cp %{SOURCE3} .

%build
CFLAGS="%{optflags}" make

%install
# The install target recreates usb_modeswitch_dispatcher, which is racy in respect to its
# installation. install-common just uses the file from the build phase. boo#998641
make DESTDIR=%{buildroot} install-common %{?_smp_mflags} UDEVDIR=%{buildroot}%{_udevdir}
install -Dm 444 usb_modeswitch@.service %{buildroot}%{_unitdir}/usb_modeswitch@.service

cd %{source_name}-data-%{date}
make DESTDIR=%{buildroot} install %{?_smp_mflags} RULESDIR=%{buildroot}%{_udevdir}/rules.d

%fdupes -s %{buildroot}

%pre
%service_add_pre usb_modeswitch@.service

%post
%service_add_post usb_modeswitch@.service

%preun
%service_del_preun usb_modeswitch@.service

%postun
%service_del_postun usb_modeswitch@.service

%files
%license COPYING
%doc README device_reference.txt parameter_reference.txt
%{_sbindir}/usb_modeswitch
%{_sbindir}/usb_modeswitch_dispatcher
%{_udevdir}/usb_modeswitch
%{_unitdir}/usb_modeswitch@.service
%{_localstatedir}/lib/usb_modeswitch
%config %{_sysconfdir}/usb_modeswitch.conf
%{_mandir}/man1/usb_modeswitch.1%{?ext_man}
%{_mandir}/man1/usb_modeswitch_dispatcher.1%{?ext_man}

%files data
%{_datadir}/usb_modeswitch/
%{_udevdir}/rules.d/40-usb_modeswitch.rules

%changelog
* Fri Nov 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_usb_modeswitch@.service.patch
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.6.1:
  Wrapper now handles devices with non-continuous interface numbering:
  www.draisberghof.de/usb_modeswitch/bb/viewtopic.php?f=2&t=2915&p=19605
  (thanks to Jakub Vaněk); catch error with retrieving the active confi-
  guration, exit gracefully
- use https for downloads, spec-cleaner run
* Mon Dec 23 2019 enzokiel@kabelmail.de
- Update to version 2.6.0
  * Removed included libjim source alltogether
  * Rewrote parts of the dispatcher script to make location of
    global config file into a parameter: --config-file, so it can be
    customised now
  * Replaced tcl helper file for jim embedding with a sh script,
    dropping the install dependency on a tcl interpreter
    (Attention maintainers!)
  * Changed Makefile to prevent parallel build issues as reported
    here:
    http://www.draisberghof.de/usb_modeswitch/bb/viewtopic.php?f=2&t=2829,
    make targets have changed names (Attention maintainers!)
- Update usb-modeswitch-data package to version 20191128
  * Slight change of the 'skipping' rules to avoid unnecessary
    checks (thanks to Florian Zumbiehl)
  * Added devices: [03f0:0857] HP lt4220, [05c6:1000:uMa=Qualcomm]
    Venus Fast2, [0bda:1a2b] D-Link DWA-171 Wifi Dongle,
    [0e8d:2870] COMFAST CF-WU782AC WiFi Dongle, [12d1:15ee]
    Vodafone/Huawei K5160, [12d1:1f0a] Vodafone/Huawei R218h
    (lkly compat. to E5573cs), [1410:9030] Novatel USB730L,
    [1410:b00c] Novatel MiFi 6620L, [15eb:a403] Abit AK-020,
    [161c:f010] KuWfi 4g LTE, [19d2:1421] ZTE MF833V / Telewell
    TW-LTE v2, [1c9e:3003] 4G System XS W21s, [1c9e:f030] JioFi
    JMR1040, [2001:ac01] D-Link DWM-222 A2, [2020:2030] Telewell
    TW-LTE / Olicard 600 / Digisol BG-BA4305, [2357:0601] TP-Link
    UE300, [2fd4:9aff] 4G Systems W1208, [413c:81a2] Dell DW5806,
    [413c:81a3] Dell DW5570, [413c:81a4] Dell DW5570e, [413c:81a8]
    Dell DW5808, [413c:81b1] Dell DW5809e, [413c:81b3] Dell DW5809e,
    [413c:81d7] Dell DW5821e, [413c:81e0] Dell DW5821e-eSIM
  * Corrected/amended configs: [057c:62ff] AVM Fritz!Wlan USB
    Sticks (added target 8602), [1199:0fff] Sierra devices
    (3 erroneous target IDs removed)
- Fixed usb_modeswitch-fix_fsf_address.patch
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Sun Apr 15 2018 enzokiel@kabelmail.de
- Update to version 2.5.2
  * Bugfix release: fixed additional MessageContent parameters not
    working, reported by Frank Schmirler (see
    http://draisberghof.de/usb_modeswitch/bb/viewtopic.php?p=18369).
  * Fixed "early crash" when killed before libusb context
    initialization (see
    https://bugzilla.redhat.com/show_bug.cgi?id=1358472), reported
    by Lubomir Rinteln.
  * Fixed bad string reference, reported by Lubomir Rintel, (see
    http://draisberghof.de/usb_modeswitch/bb/viewtopic.php?p=18238).
  * Fixed detection of systemd if /sbin/init is a cascaded symlink
    (see
    http://draisberghof.de/usb_modeswitch/bb/viewtopic.php?p=18218).
  * Fixed quirk in help message from usb_modeswitch binary.
* Tue Aug 22 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.5.1
  * New parameter "HuaweiAltMode", uses an alternative Huawei
    standard bulk message which will either provide NCM
    (newer modems) or plain PPP ports (older modems).
  * New option in the global configuration file
    "HuaweiAltModeGlobal", allowing easy override of
    "HuwaeiNewMode" with "HuaweiAltMode".
  * Reworked USB configuration switching, configuring a device
    reset first before setting the target configuration.
  * Improved driver detachment, now taking all configured
    interfaces into account.
- Update usb-modeswitch-data package to version 20170806
  * Added devices: [03f0:371d] HP un2430, [03f0:4b1d] HP hs2434,
    [03f0:4e1d] HP lt4111, [03f0:a31d] HP lt4132,
    [0846:0fff] Netgear AirCard 779S,
    [12d1:15ec] Vodafone/Huawei K5150.
  * Corrected/amended configs: [0922:1003] Dymo LabelManager 420P,
    [0922:1007] Dymo LabelManager Wireless PnP,
    [1199:0fff] Sierra devices.
  * Removed configs: [1004:61aa] LG VL600.
- Updated file device_reference.txt.
- Added file parameter_reference.txt
* Fri Feb 24 2017 joerg.lorenzen@ki.tng.de
- Update usb-modeswitch-data package to version 20170205
  * Bugfix release: Removed all catch-all fallback config files as
    they can affect unrelated devices - fixes (rh#1374913).
* Sat Jan 28 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.5.0
  * ATTENTION: Parameter transmitted from udev now reduced to %%k
    (kernel name), however, rules file parameters can be '%%b/%%k' or
    '%%k' - this fixes issues with parameter handling by the systemd
    unit file.
  * Remove endpoint reset ahead of bulk message transmission, only
    reset if endpoints are actually stalled, helping with quirky
    device behaviour (see www.draisberghof.de/usb_modeswitch/bb/
    viewtopic.php?f=2&t=2582 ).
  * Stability fix by making a buffer in the config parser static,
    preventing problems seen in Fedora (thanks to Lubomir Rintel
    for patches and hints regarding the three previous issues).
  * Removed premature driver unbinding in wrapper which could
    disrupt certain devices already in target mode (reported by
    Aleksander Morgado).
  * Improved check for determining install mode (essential with
    generic config files present, e.g. 12d1:#linux).
- Update usb-modeswitch-data package to version 20170120.
* Fri Oct 28 2016 joerg.lorenzen@ki.tng.de
- Update usb-modeswitch-data package to version 20160803.
- Added systemd as BuildRequires and fixed install of service file.
* Tue Sep 13 2016 stefan.bruens@rwth-aachen.de
- Avoid a race in make install, which lead to packaging a truncated
  usb_modeswitch_dispatcher script. Fixes boo#998641
* Sat Aug 20 2016 stefan.bruens@rwth-aachen.de
- Install required usb_modeswitch@.service, fixes boo#994763
* Fri Jul 29 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.4.0
  * ATTENTION: All ad-hoc driver binding code (using new_id driver
    attribute) removed - was a potential source of side effects and
    should now be obsoleted by good kernel support for modems.
  * Added "dummy" setting for config files, to conditionally
    refrain from handling a device (see this topic:
    www.draisberghof.de/usb_modeswitch/bb/viewtopic.php?f=4&t=2458).
  * Extended StandardEject sequence to include LUN 1, required for
    some D-Link devices.
  * Add device class 239 ("miscellaneous") to sanity check (thanks
    to Daniel Drake for reporting).
  * udev shell script - removed driver binding, removed almost all
    waiting and forking, improved check for systemd (thanks to
    Daniel Drake for problem analysis and solution, see this
    topic/patch:
    www.draisberghof.de/usb_modeswitch/bb/viewtopic.php?p=16777#p16777,
    gist.github.com/dsd/9f83c4830ab78ce94078aedb2cf16a8f).
* Tue Feb 16 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.3.0
  * ATTENTION: -I flag is now history and being ignored - determining
    SCSI attributes is really an 'outside task'.
  * -n flag (NeedResponse) is being ignored, CSW response will now
    always be read.
  * Introduction of parameter "OptionMode", wrapping the standard
    bulk message for all newer Huawei devices.
  * Fixed missing variable initialization in dispatcher script which
    could lead to crash (thanks, Dmitry Kunilov!).
  * Fixed bug which prevented early logging.
  * Fixed success report for Cisco AM10.
  * Some source code formatting and clean-up.
- Removed fix for bnc#899013, fixed upstream.
* Fri Nov 13 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.2.6
  * Renamed function abort(), avoiding possible conflicts in static
    builds with libjim (thanks, Gustavo Zacharias).
  * Removed storage class check of interface 0 from dispatcher,
    enabling new multi-config devices in data package 20151101.
* Fri Jul 24 2015 jweberhofer@weberhofer.at
- Removed unused usb_modeswitch-data.rpmlintrc
- Removed changelog from documentation
- Cleaned up specfile
- Update to version 2.2.5
  * Fixed bug in configuration check, possibly leading to segfault (thanks,
    Leonid Lisovskiy);
  * fixed Pantech commandline parameter evaluation (was not working at all);
  * added driver unbind step via sysfs in wrapper, getting rid of the
    USB subsystem complaint "interface 0 claimed by usb-storage while
    'usb_modeswitch' <does this and that>"
- Update to version 2.2.4
  * Fixed buggy check of USB configuration selection (possibly leading
    to segfault), tested with Alcatel X602D;
  * removed call to 'libusb_strerror'
    from libusb initialization - not available in earlier libusb1 versions
- Update to version 2.2.3
  * Fixed problem arising with systemd version 221 (220 untested), which
    affects starting the usb_modeswitch systemd unit from the sh script
    (reported by Archlinux users)
- Update to version 2.2.2, 2015/06/27
  * Added catch for libusb init error (thanks, Henrik Gustafsson);
  * removed global function result variable; added catch for USB configuration
    read error (both thanks to "otila");
  * fixed wrapper script where port search for symlinking modem port was
    broken ("/dev/gsmmodem");
  * changed PantechMode parameter to represent different targets;
  * added global config option to disable MBIM checking and setting
    alltogether (request from "kai");
  * changed udev sh script so that systemd processing takes precedence over
    upstart;
  * changed systemd template unit parameter to avoid escaping problems
- Update the data package to version 20150627
* Sat Apr 25 2015 coolo@suse.com
- use pkgconfig to detect udev install directory to avoid problems
  during bootstrap
* Wed Apr  8 2015 p.drouand@gmail.com
- Update to version 2.2.1
  * Fixed unreliable switching function for Cisco AM10
- Update the data package to version 20150115
- Update device_reference.txt
* Tue Mar 24 2015 cxiong@suse.com
- add usb_modeswitch-fix_fsf_address.patch
  * Update FSF address.
* Tue Nov  4 2014 andrea@opensuse.org
- removed patch obsolete huawei-timing.patch to fix boo#903753
* Mon Nov  3 2014 andrea@opensuse.org
- new upstream version 2.2.0
  * Introduction of parameter "HuaweiNewMode", wrapping the standard bulk
    message for all newer Huawei devices; support for generic fall-back
    config files, combined with OS switch (per vendor ID), implementation
    to use a specific switching command on Android for all Huawei devices
    (see README of data package for details); this change was suggested
    by Huawei
* Sat Oct 11 2014 andrea@opensuse.org
- fix for bnc #899013
* Thu Oct  2 2014 andrea@opensuse.org
- upgraded the data package to version 20140529
* Mon May 26 2014 tittiatcoke@gmail.com
- Update to 2.1.1
  * Code cleanup
  * Better usage of libusb1
  * -I flag meaning reversed, default is to skip SCSI inquiry
  * Experimental systemd and upstart integration
* Thu May 16 2013 mvyskocil@suse.com
- drop /bin/eject from dependencies, it is no longer called
- install device_reference.txt as %%doc
- use URL in all relevant Source tags
- drop obsoleted sections from spec
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to 1.2.5:
  * Initial support for MBIM devices, use with data package >= 20121109;
    checking for these is the automatic default, new parameter NoMBIMCheck
    prevents the check per device in case of problems; new global option
    to set "delay_use" of usb-storage (as low values may prevent
    mode-switching);
  * fix for handling multi-configuration devices (thanks
    to Bjørn Mork for advice)
- Removed files:
  * add_alcatel_ot_x220d.patch: supported on upstream release
  * 1bbb:f017: supported on upstream release
- Adapt huawei-timing.patch for 1.2.5
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev directory location
* Fri Sep 28 2012 gschlotter@suse.com
- huawei-timing.patch:
  * fixed timing issues with huawei devices (E173, ...)
    bnc#740354
* Fri Jul 20 2012 javier@opensuse.org
- Update data package to 20120531
- Add Alcatel OT-X220D support
* Sun Apr  1 2012 gankov@opensuse.org
- New data package 20120120
- Update to 1.2.3
- Add BuildRequires tcl
- Using fdupes
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue May 10 2011 andrea@opensuse.org
- New data package 20110227
- Update to 1.1.7:
  * Attention: paths for runtime files and database have changed!
  * fix for configuration setting race (thanks to Amit Mendapara);
  * discovered incompatibility between Tcl versions <= 8.3
    and >=8.4, so 8.4 is the minimum prerequisite now;
* Mon Jan 10 2011 dmueller@suse.de
- fix dependency
* Wed Jan  5 2011 bili@novell.com
- Update to 1.1.6 including:
  * Moved warm-boot driver binding to sh wrapper, was unreliable
    in 1.1.5;
  * initial device checking includes current "bConfigurationValue"
    now, should work with config setting for multiple devices;
  * made tcl script conform to limitations of "jimsh", the minimal
    tcl shell (hint from Barry Kauler);
  * fixes for "usbserial" fallback (driver binding for old systems);
  * in the C program, changed parameter "MessageDelay" (hitherto
    unused) to "ReleaseDelay", to be used in one device configuration
- Update database to 20101222 state.
* Tue Dec 14 2010 aj@suse.de
- Update to 1.1.5 including:
  * Added special control message for Kobil devices
  * try to get active configuration for interface class checking
  * fixed "0000" target product ID - again
  * new bash and tcl wrapper logic: the convenience functions for
    driver binding and symlinking will now start the tcl shell
    ONLY for known devices;
- Update database to 20101202 state.
* Mon Aug 23 2010 pth@suse.de
- Update to 1.1.4
  * The package should work at boot time now (cold and warm)
  * Product IDs of "0000" do exist but were not accepted, fixed
  * Response endpoint is now always detected
  * Wrapper script can now work with a packed collection of config
    files as well as with the plain folder of files
  * Wrapper fix for the symlink feature: handling of multiple interrupt
    ports was incomplete
  * Wrapper does not longer use a temporary file for the symlink feature
* Thu Jul  8 2010 andrea@opensuse.org
- New upstream version 1.1.3
  * Added delay option to separate multiple message
    transfers by millisecs
  * fixed (possibly dangerous) sloppy string handling
  * Added "clear_halt" for response endpoint
  * Small additions in Makefile (install with -D)
  * Changes in option handling (no more default config file!)
  * Symlink feature in wrapper can now cope with devices providing
    more than one interrupt port
  * Wrapper now ignores package manager leftovers in config folder
  * Replaced bash-specific syntax in wrapper
  * Changed ZTE skipping (if existing rules are found) to warning
- update data package to version 20100707
- spec file clean up (sources support 'make install')
* Tue May 18 2010 aj@suse.de
- Cleanup spec file.
* Tue May 11 2010 tuoma_mel@inbox.ru
- update to version 1.1.2
* Wed Jan 21 2009 seife@suse.de
- add dependency on /bin/eject (used in the udev rules)
* Wed Jan 21 2009 seife@suse.de
- update usb_modeswitch.conf (from 2009-01-13)
- add udev rules and a script to create them from the config file
* Mon Jan 12 2009 seife@suse.de
- update to version 0.9.6
  - special modes added for Sierra and Sony Ericsson, new devices
* Fri Nov  7 2008 seife@suse.de
- copied the package from home:perosb (Thanks!)
- added the latest config file from the home page
- install README
- use RPM_OPT_FLAGS
- enable useful debug info by not stripping the binary
